@@ -34,10 +34,17 @@ releases.</p>
   </tr>
 </table>
 
+<h1>v2.52 (2008-09-07)</h1>
+
+<ul>
+	<li class="star">Updated kernel components for Linux 2.6.27</li>
+	<li class="star">Updated userspace code for libHX 1.25</li>
+</ul>
+
 <h1>v2.51 (2008-05-15)</h1>
 
 <ul>
-	<li class="start">Updated rpldhk and rpldev for Linux 2.6.25,
+	<li class="star">Updated rpldhk and rpldev for Linux 2.6.25,
 		OpenBSD 4.3, FreeBSD 7.0, NetBSD 4.0</li>
 </ul>
 
@@ -611,7 +618,7 @@ recompile without reboot.)</p>
   <li class="star"><code>START_INFOD</code> in the default distribution is now "<code>yes</code>"</li>
   <li class="star">(all): big endian was never selected due to a typo in <code>__BYTE_ORER</code></li>
   <li class="plus">supporting Kernel 2.6.8-14 (SUSE) and 2.6.8 (vanilla)</li>
-  <li class="star">Kernel patches moved into their own folder "<code>kpatch</code>"</li>
+  <li class="star">Kernel patches moved into their own directory "<code>kpatch</code>"</li>
 </ul>
 
 <h1>v0.88 (2004-09-09)</h1>
