@@ -18,8 +18,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <syslog.h>
+#include <unistd.h>
 
-#include <libHX.h>
+#include <libHX/arbtree.h>
 #include "dev.h"
 #include "lib.h"
 #include "rdsh.h"
@@ -88,7 +89,7 @@ void log_close(struct tty *tty)
 	close(tty->fd);
 	tty->fd = -1;
 	if (tty->log != NULL) {
-		hmc_free(tty->log);
+		HXmc_free(tty->log);
 		tty->log = NULL; /* for infod */
 	}
 
