@@ -1,7 +1,6 @@
 /*
  *	ttyrpld/user/rplctl.c
- *	Copyright © CC Computer Consultants GmbH, 2004 - 2007
- *	Contact: Jan Engelhardt <jengelh [at] computergmbh de>
+ *	Copyright © Jan Engelhardt <jengelh [at] medozas de>, 2004 - 2008
  *
  *	This file is part of ttyrpld. ttyrpld is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
@@ -19,8 +18,10 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
-#include <libHX.h>
+#include <libHX/option.h>
+#include <libHX/string.h>
 #include "dev.h"
 #include "lib.h"
 #include "rdsh.h"
