@@ -1,7 +1,6 @@
 /*
  *	ttyrpld/user/rpld.c
- *	Copyright © CC Computer Consultants GmbH, 2004 - 2007
- *	Contact: Jan Engelhardt <jengelh [at] computergmbh de>
+ *	Copyright © Jan Engelhardt <jengelh [at] medozas de>, 2004 - 2008
  *
  *	This file is part of ttyrpld. ttyrpld is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
@@ -31,7 +30,10 @@
 #include <time.h>
 #include <unistd.h>
 
-#include <libHX.h>
+#include <libHX/arbtree.h>
+#include <libHX/misc.h>
+#include <libHX/option.h>
+#include <libHX/string.h>
 #include "compat.h"
 #include "dev.h"
 #include "rpl_endian.h"
@@ -59,7 +61,7 @@ static void evt_open(struct rpldev_packet *, struct tty *, int);
 static void log_open(struct tty *);
 static void log_write(struct rpldev_packet *, struct tty *, int);
 
-static int check_parent_directory(const hmc_t *);
+static int check_parent_directory(const hxmc_t *);
 static void fill_info(struct tty *, const char *);
 
 static int init_device(const char *);
@@ -442,7 +444,7 @@ static void log_write(struct rpldev_packet *packet, struct tty *tty, int fd)
 }
 
 //-----------------------------------------------------------------------------
-static int check_parent_directory(const hmc_t *s)
+static int check_parent_directory(const hxmc_t *s)
 {
 	char *path = alloca(strlen(s) + 1), *p;
 
@@ -543,7 +545,7 @@ static void fill_info(struct tty *tty, const char *aux_sdev)
 		strftime(fmtime, sizeof(fmtime), "%H%M%S", &now_tm);
 	}
 
-	hmc_free(tty->log);
+	HXmc_free(tty->log);
 	catalog  = HXformat_init();
 	HXformat_add(catalog, "DATE", fmday,  HXTYPE_STRING);
 	HXformat_add(catalog, "TIME", fmtime, HXTYPE_STRING);
@@ -842,5 +844,3 @@ static bool read_config_bp(const char *app_path, const char *file)
 	free(fpath);
 	return read_config(construct);
 }
-
-//=============================================================================
